
BEGIN {
  unless ($ENV{AUTHOR_TESTING}) {
    require Test::More;
    Test::More::plan(skip_all => 'these tests are for testing by the author');
  }
}

use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.006008
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib  ) );
__DATA__
DROLSKY
DROLSKY's
Rolsky
Rolsky's
API
CPAN
Cholet
Dumont
Goess
Manfredi
Miyagawa
PayPal
Pfeiffer
STDERR
STDOUT
Schilli
Straup
Subclasses
Swartz
Tatsuhiko
UTF
apache
appenders
auth
authpriv
autoflushed
classname
crit
emerg
filename
ident
kern
logopt
multi
params
smtp
stderr
subclass's
subclasses
uucp
Dave
autarch
devnull
Karen
Etheridge
ether
Olaf
Alders
olaf
Ross
Attrill
ross
swartz
unknown
Whitney
Jackson
whitney
lib
Log
Dispatch
Syslog
Email
MailSend
Null
Handle
MIMELite
Output
MailSender
Screen
Base
MailSendmail
Code
Conflicts
File
Locked
ApacheLog
